==> org.eclipse.glsp.graph.source_0.9.0.jar: org/eclipse/glsp/graph/builder/impl/GIssueBuilder.java <==
/********************************************************************************
 * Copyright (c) 2019 EclipseSource and others.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * https://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the Eclipse
 * Public License v. 2.0 are satisfied: GNU General Public License, version 2
 * with the GNU Classpath Exception which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 ********************************************************************************/
package org.eclipse.glsp.graph.builder.impl;

import org.eclipse.glsp.graph.GIssue;
import org.eclipse.glsp.graph.GSeverity;
import org.eclipse.glsp.graph.GraphFactory;
import org.eclipse.glsp.graph.builder.GBuilder;

public class GIssueBuilder extends GBuilder<GIssue> {
   private GSeverity severity;
   private String message;

   public GIssueBuilder severity(GSeverity severity) {
      this.severity = severity;
      return this;
   }

   public GIssueBuilder message(String message) {
      this.message = message;
      return this;
   }

   @Override
   protected GIssue instantiate() {
      return GraphFactory.eINSTANCE.createGIssue();
   }

   @Override
   protected void setProperties(GIssue issue) {
      issue.setMessage(message);
      issue.setSeverity(severity);
   }

}

==> org.eclipse.glsp.graph.source_2.5.0.jar: org/eclipse/glsp/graph/builder/impl/GIssueBuilder.java <==
/********************************************************************************
 * Copyright (c) 2019-2024 EclipseSource and others.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * https://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the Eclipse
 * Public License v. 2.0 are satisfied: GNU General Public License, version 2
 * with the GNU Classpath Exception which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 ********************************************************************************/
package org.eclipse.glsp.graph.builder.impl;

import org.eclipse.glsp.graph.GIssue;
import org.eclipse.glsp.graph.GSeverity;
import org.eclipse.glsp.graph.GraphFactory;
import org.eclipse.glsp.graph.builder.GBuilder;

public class GIssueBuilder extends GBuilder<GIssue> {
   private String severity;
   private String message;

   public GIssueBuilder severity(GSeverity severity) {
      return this.severity(severity.getLiteral());
   }

   public GIssueBuilder severity(String severity) {
      this.severity = severity;
      return this;
   }

   public GIssueBuilder message(String message) {
      this.message = message;
      return this;
   }

   @Override
   protected GIssue instantiate() {
      return GraphFactory.eINSTANCE.createGIssue();
   }

   @Override
   protected void setProperties(GIssue issue) {
      issue.setMessage(message);
      issue.setSeverity(severity);
   }

}
